Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(19)

Unified Diff: dart/tests/standalone/io/regress_21160_test.dart

Issue 609893003: Use less data for regression_21160_test to eliminate simulator timeouts (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dart/tests/standalone/io/regress_21160_test.dart
diff --git a/dart/tests/standalone/io/regress_21160_test.dart b/dart/tests/standalone/io/regress_21160_test.dart
index 98c9b68f9169996b40190b9741c5b29202859001..69cbcf19df9853af9186cdbd9343f51d42274ffc 100644
--- a/dart/tests/standalone/io/regress_21160_test.dart
+++ b/dart/tests/standalone/io/regress_21160_test.dart
@@ -10,9 +10,9 @@ import "dart:async";
import "dart:io";
import "dart:typed_data";
// 1 MB of i%256 data.
Uint8List DATA = new Uint8List.fromList(
- new List.generate(1024 * 1024, (i) => i % 256));
+ new List.generate(10 * 1024, (i) => i % 256));
Future<SecureServerSocket> startServer() {
return SecureServerSocket.bind("localhost",
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -10,9 +10,9 @@ import "dart:async";
import "dart:io";
import "dart:typed_data";
-// 1 MB of i%256 data.
+// 10 KiB of i%256 data.
Uint8List DATA = new Uint8List.fromList(

Powered by Google App Engine
This is Rietveld 408576698